@@ -10,7 +10,8 @@ use Scalar::Util 'blessed';
 
 # DEPRECATED in Tiger Face!
 use overload '""' => sub {
-  deprecated 'Stringification support in Mojo::Collection is DEPRECATED';
+  deprecated 'Stringification support in Mojo::Collection is DEPRECATED'
+    . ' in favor of Mojo::Collection::join';
   shift->join("\n");
 };
 use overload bool => sub {1}, fallback => 1;
@@ -19,10 +20,10 @@ our @EXPORT_OK = ('c');
 
 # DEPRECATED in Tiger Face!
 sub AUTOLOAD {
-  deprecated 'Mojo::Collection::AUTOLOAD is DEPRECATED in favor of'
-    . ' Mojo::Collection::map';
   my $self = shift;
   my ($package, $method) = our $AUTOLOAD =~ /^(.+)::(.+)$/;
+  deprecated "Mojo::Collection::AUTOLOAD ($method) is DEPRECATED"
+    . ' in favor of Mojo::Collection::map';
   croak "Undefined subroutine &${package}::$method called"
     unless blessed $self && $self->isa(__PACKAGE__);
   return $self->map($method, @_);
@@ -117,6 +118,8 @@ sub sort {
 
 sub tap { shift->Mojo::Base::tap(@_) }
 
+sub to_array { [@{shift()}] }
+
 sub uniq {
   my %seen;
   return $_[0]->new(grep { !$seen{$_}++ } @{$_[0]});
@@ -143,6 +146,7 @@ Mojo::Collection - Collection
   # Manipulate collection
   my $collection = Mojo::Collection->new(qw(just works));
   unshift @$collection, 'it';
+  say $collection->join("\n");
 
   # Chain methods
   $collection->map(sub { ucfirst })->shuffle->each(sub {
@@ -150,9 +154,6 @@ Mojo::Collection - Collection
     say "$count: $word";
   });
 
-  # Stringify collection
-  say $collection->join("\n");
-
   # Use the alternative constructor
   use Mojo::Collection 'c';
   c(qw(a b c))->join('/')->url_escape->say;
@@ -330,6 +331,12 @@ from the results.
 
 Alias for L<Mojo::Base/"tap">.
 
+=head2 to_array
+
+  my $array = $collection->to_array;
+
+Turn collection into array reference.
+
 =head2 uniq
 
   my $new = $collection->uniq;
