@@ -10,7 +10,7 @@ use Socket qw(IPPROTO_TCP TCP_NODELAY);
 # Non-blocking name resolution requires Net::DNS::Native
 use constant NDN => $ENV{MOJO_NO_NDN}
   ? 0
-  : eval 'use Net::DNS::Native 0.12 (); 1';
+  : eval 'use Net::DNS::Native 0.14 (); 1';
 my $NDN = NDN ? Net::DNS::Native->new(pool => 5, extra_thread => 1) : undef;
 
 # TLS support requires IO::Socket::SSL
@@ -43,9 +43,9 @@ sub connect {
 
   # Blocking name resolution
   $_ && s/[[\]]//g for @$args{qw(address socks_address)};
-  my $address = $args->{socks_address} || ($args->{address} ||= 'localhost');
+  my $address = $args->{socks_address} || ($args->{address} ||= '127.0.0.1');
   return $reactor->next_tick(sub { $self && $self->_connect($args) })
-    unless NDN && $address ne 'localhost' && !$args->{handle};
+    if !NDN || $args->{handle};
 
   # Non-blocking name resolution
   my $handle = $self->{dns}
@@ -78,10 +78,7 @@ sub _connect {
   my $handle;
   my $address = $args->{socks_address} || $args->{address};
   unless ($handle = $self->{handle} = $args->{handle}) {
-    my %options = (
-      PeerAddr => $address eq 'localhost' ? '127.0.0.1' : $address,
-      PeerPort => _port($args)
-    );
+    my %options = (PeerAddr => $address, PeerPort => _port($args));
     %options = (PeerAddrInfo => $args->{addr_info}) if $args->{addr_info};
     $options{Blocking} = 0;
     $options{LocalAddr} = $args->{local_address} if $args->{local_address};
@@ -96,6 +93,8 @@ sub _connect {
     ->watch($handle, 0, 1);
 }
 
+sub _port { $_[0]->{socks_port} || $_[0]->{port} || ($_[0]->{tls} ? 443 : 80) }
+
 sub _ready {
   my ($self, $args) = @_;
 
@@ -111,8 +110,6 @@ sub _ready {
   $self->_try_socks($args);
 }
 
-sub _port { $_[0]->{socks_port} || $_[0]->{port} || ($_[0]->{tls} ? 443 : 80) }
-
 sub _socks {
   my ($self, $args) = @_;
 
@@ -268,8 +265,8 @@ implements the following new ones.
   $client->connect(address => '127.0.0.1', port => 3000);
 
 Open a socket connection to a remote host. Note that non-blocking name
-resolution depends on L<Net::DNS::Native> (0.12+) and TLS support on
-L<IO::Socket::SSL> (1.84+).
+resolution depends on L<Net::DNS::Native> (0.14+), SOCKS5 support on
+L<IO::Socket::Socks> (0.64), and TLS support on L<IO::Socket::SSL> (1.84+).
 
 These options are currently available:
 
@@ -279,7 +276,7 @@ These options are currently available:
 
   address => 'mojolicio.us'
 
-Address or host name of the peer to connect to, defaults to C<localhost>.
+Address or host name of the peer to connect to, defaults to C<127.0.0.1>.
 
 =item handle
 
